@@ -1,4 +1,4 @@
-__all__ = ('CacheMixin', 'CacheObjectMixin', 'FlushCache')
+__all__ = ('CacheMixin', 'CacheObjectMixin')
 
 import os
 from typing import Union
@@ -14,36 +14,29 @@ User = get_user_model()
 class BaseCacheMixin:
     _cache_period: int = None
 
-    @property
-    def _data_key(self):
-        return self._point_id.id
+    @log
+    def flush_cache(self):
+        """Delete Redis cache for current endpoint"""
+        cache.delete(self._get_cache_key())
 
     @property
     def _cache(self):
         if self._memory_cache is None:
-            all_cache_data = self.__get_cache()
-            self._memory_cache = all_cache_data.get(self._data_key) if all_cache_data else None
-            if os.getenv('IS_ENABLE_API_LOG') and self._memory_cache is not None:
-                print(f'GET REDIS {self}')
+            try:
+                cache_data = cache.get(self._get_cache_key())
+                self._memory_cache = cache_data
+                if os.getenv('IS_ENABLE_API_LOG') and cache_data is not None:
+                    print(f'GET REDIS {self}')
+            except ModuleNotFoundError:
+                cache.set(self._get_cache_key(), None, None)
         return self._memory_cache
 
     @_cache.setter
-    def _cache(self, value: any):
+    def _cache(self, value):
         if value is not None:
-            data = self.__get_cache()
-            ext_data = {f'{self._data_key}': value}
-            data = dict(**data, **ext_data) if data else ext_data
-            self.__set_cache(data)
+            cache.set(self._get_cache_key(), value, self._cache_period)
             self._memory_cache = value
 
-    @log
-    def flush_cache(self):
-        """Delete Redis cache for current endpoint"""
-        data = self.__get_cache()
-        if data:
-            data.pop(self._data_key, False)
-            self.__set_cache(data)
-
     def _get_related_points(self) -> list:
         """Set related points here"""
         return list()
@@ -53,38 +46,48 @@ class BaseCacheMixin:
         for point in related_points:
             point.flush_cache()
 
-    def __set_cache(self, data):
-        cache.set(self.__cache_key, data, self._cache_period)
-
-    def __get_cache(self) -> Union[None, dict]:
-        try:
-            return cache.get(self.__cache_key)
-        except ModuleNotFoundError:
-            self.__set_cache(None)
+    def _get_cache_key(self):
+        cache_key = f'user{getattr(self._user, "id")}_{self._point_id.id}'
+        cache_key_with_suffix = cache_key if not self._cache_key_suffix else f'{cache_key}{self._cache_key_suffix}'
+        return cache_key_with_suffix
 
     @property
-    def __cache_key(self):
-        return getattr(self._user, 'id')
+    def _cache_key_suffix(self):
+        if self._query_params:
+            suffix = ''
+            for key, item in self._query_params.items():
+                suffix += f'_{key}_{item}'
+            return suffix
 
 
-class CacheMixin(BaseCacheMixin):
-
-    def __init__(self, user: User, is_async: bool = False, timeout: tuple = (30, 30)):
-        super().__init__(user, is_async, timeout)
-        self._memory_cache = None
-        self._payload = None
-
+class GetCacheMixin:
     def _get(self) -> dict:
         if self._cache is not None:
             return self._cache
         return super()._get()
 
+
+class CacheMixin(GetCacheMixin, BaseCacheMixin):
+
+    def __init__(self,
+                 user: User,
+                 query_params: dict = None,
+                 is_async: bool = False,
+                 timeout: tuple = (30, 30)
+                 ):
+        super().__init__(user=user,
+                         query_params=query_params,
+                         is_async=is_async,
+                         timeout=timeout,
+                         )
+        self._memory_cache = None
+        self._payload = None
+
     def _post(self, payload: dict):
         self._payload = payload
-        response = super()._post(payload)
+        super()._post(payload)
         self._memory_cache = None
         self._flush_cache_related_points()
-        return response
 
     def _post_file(self, file, file_name, type_):
         super()._post_file(file, file_name, type_)
@@ -92,7 +95,7 @@ class CacheMixin(BaseCacheMixin):
         self._flush_cache_related_points()
 
 
-class CacheObjectMixin(BaseCacheMixin):
+class CacheObjectMixin(GetCacheMixin, BaseCacheMixin):
 
     def __init__(self,
                  user: User,
@@ -100,36 +103,16 @@ class CacheObjectMixin(BaseCacheMixin):
                  is_async: bool = False,
                  timeout: tuple = (30, 30)
                  ):
-        super().__init__(user, lookup_field_value, is_async, timeout)
+        super().__init__(user=user,
+                         lookup_field_value=lookup_field_value,
+                         is_async=is_async,
+                         timeout=timeout
+                         )
         self._memory_cache = None
         self._payload = None
 
-    def _get(self) -> dict:
-        if self._cache is not None:
-            return self._cache
-        return super()._get()
-
     def _put(self, payload: dict):
         self._payload = payload
         super()._put(payload)
         self._memory_cache = None
         self._flush_cache_related_points()
-
-    @property
-    def _data_key(self):
-        return f'{super()._data_key}_{self._lookup_field_value}'
-
-
-class FlushCache:
-    """"Delete cache for all API points"""
-
-    def __init__(self, user: User):
-        self._user = user
-
-    @log
-    def flush_cache(self):
-        cache.delete(self._cache_key)
-
-    @property
-    def _cache_key(self):
-        return getattr(self._user, 'id')
