@@ -10,6 +10,7 @@ from typing import Union
 import requests
 from django.conf import settings
 from django.contrib.auth import get_user_model
+from django.utils.http import urlencode
 from google.auth.transport.requests import Request as GoogleRequest
 from google.cloud import tasks_v2
 from google.oauth2 import id_token
@@ -25,12 +26,13 @@ class HttpClient(abc.ABC):
     """Abstract HTTP client"""
 
     _client = None
+    _project = 'expressmoney' if settings.IS_PROD else 'expressmoney-dev-1'
 
     def __init__(self,
                  service: str = 'default',
                  path: str = '/',
+                 query_params: Union[None, dict] = None,
                  access_token: str = None,
-                 project: str = 'expressmoney',
                  ):
         """
         Common params for all http clients
@@ -38,12 +40,11 @@ class HttpClient(abc.ABC):
             service: 'default'
             path: '/user'
             access_token: 'Bearer DFD4345345D'
-            project: 'expressmoney'
         """
         self._service = service
         self._path = path
+        self._query_params = query_params
         self._access_token = access_token
-        self._project = project
 
     @abc.abstractmethod
     def get(self):
@@ -67,7 +68,6 @@ class BaseTasks(HttpClient):
                  service: str = 'default',
                  path: str = '/',
                  access_token: str = None,
-                 project: str = 'expressmoney',
                  location: str = 'europe-west1',
                  queue: str = 'attempts-1',
                  in_seconds: int = None):
@@ -77,13 +77,12 @@ class BaseTasks(HttpClient):
             service: 'default'
             path: '/user'
             access_token: 'Bearer DFD4345345D'
-            project: 'expressmoney'
             queue: 'my-appengine-queue'
             location: 'europe-west1'
             in_seconds: None
         """
-        super().__init__(service, path, access_token, project)
-        self._queue_path = self._client.queue_path(project, location, queue)
+        super().__init__(service, path, access_token)
+        self._queue_path = self._client.queue_path(self._project, location, queue)
         self._in_seconds = in_seconds
 
     def get(self):
@@ -155,10 +154,14 @@ class BaseRequest(HttpClient):
     def __init__(self,
                  service: str = None,
                  path: str = '/',
+                 query_params: Union[None, dict] = None,
                  access_token: str = None,
-                 project: str = 'expressmoney',
                  timeout: tuple = (30, 30)):
-        super().__init__(service, path, access_token, project)
+        super().__init__(service=service,
+                         path=path,
+                         query_params=query_params,
+                         access_token=access_token,
+                         )
         self._timeout = timeout
 
     def get(self):
@@ -224,8 +227,10 @@ class BaseRequest(HttpClient):
     @property
     def _uri(self):
         local_url = 'http://127.0.0.1:8000'
-        url = f'https://{self._service}-dot-{self._project}.appspot.com' if self._service else local_url
-        return f'{url}{self._path}'
+        domain = f'https://{self._service}-dot-{self._project}.appspot.com' if self._service else local_url
+        url = f'{domain}{self._path}'
+        url_with_params = url if self._query_params is None else f'{url}?{urlencode(self._query_params)}'
+        return url_with_params
 
     @property
     def _headers(self):
@@ -239,32 +244,43 @@ class BaseRequest(HttpClient):
 
 class Tasks(BaseTasks):
     """Google Cloud Tasks Client for Django user"""
+
     def __init__(self,
                  service: str = 'default',
                  path: str = '/',
                  user: Union[None, int, User] = None,
-                 project: str = 'expressmoney',
                  location: str = 'europe-west1',
                  queue: str = 'attempts-1',
                  in_seconds: int = None):
-
         user = None if user is None else user if isinstance(user, User) else User.objects.get(pk=user)
         access_token = RefreshToken.for_user(user).access_token if user is not None else None
-        super().__init__(service, path, access_token, project, location, queue, in_seconds)
+        super().__init__(service=service,
+                         path=path,
+                         access_token=access_token,
+                         location=location,
+                         queue=queue,
+                         in_seconds=in_seconds
+                         )
 
 
 class Request(BaseRequest):
     """HTTP Client for Django user"""
+
     def __init__(self,
                  service: str = None,
                  path: str = '/',
+                 query_params: Union[None, dict] = None,
                  user: Union[None, int, User] = None,
-                 project: str = 'expressmoney',
                  timeout: tuple = (30, 30),
                  ):
         user = None if user is None else user if isinstance(user, User) else User.objects.get(pk=user)
         access_token = RefreshToken.for_user(user).access_token if user is not None else None
-        super().__init__(service, path, access_token, project, timeout)
+        super().__init__(service=service,
+                         path=path,
+                         query_params=query_params,
+                         access_token=access_token,
+                         timeout=timeout
+                         )
 
     def _get_authorization(self) -> dict:
         authorization = super()._get_authorization()
