@@ -4,8 +4,8 @@ Endpoints handlers
 
 __all__ = ('PointRequestError', 'PointServerError', 'PointClientError', 'PointNotFound404', 'PointThrottled',
            'Point', 'ObjectPoint', 'ContractPoint', 'ContractObjectPoint',
-           'ListPointMixin', 'RetrievePointMixin', 'CreatePointMixin', 'UpdatePointMixin', 'UploadFilePointMixin',
-           'ActionPointMixin',
+           'ListPointMixin', 'RetrievePointMixin', 'ResponseMixin', 'CreatePointMixin', 'UpdatePointMixin',
+           'UploadFilePointMixin', 'ActionPointMixin',
            'ID', 'Contract', 'PaginationContract'
            )
 
@@ -93,7 +93,12 @@ class Point:
     _point_id: ID = None
 
     @log
-    def __init__(self, user: User, is_async: bool = False, timeout: tuple = (30, 30)):
+    def __init__(self,
+                 user: User,
+                 query_params: dict = None,
+                 is_async: bool = False,
+                 timeout: tuple = (30, 30)
+                 ):
         self._user = user
         self._cache = None
         self._response = None
@@ -108,6 +113,15 @@ class Point:
                               user=user,
                               )
                         )
+        self.__query_params = query_params
+
+    @property
+    def _query_params(self) -> dict:
+        if self._is_async:
+            SyncOnly('Query params only for sync queries.')
+        if not getattr(self, 'list', None):
+            PointError('Query params only for list action.')
+        return self.__query_params
 
     @property
     def _path(self):
@@ -160,7 +174,11 @@ class ObjectPoint(Point):
             raise LookupFieldValueNone('lookup_field_value not filled')
         self._lookup_field_value = lookup_field_value
         self._point_id.lookup_field_value = lookup_field_value
-        super().__init__(user, is_async, timeout)
+        super().__init__(user=user,
+                         query_params=None,
+                         is_async=is_async,
+                         timeout=timeout,
+                         )
 
     def _put(self, payload: dict):
         self._response = self._client.put(payload=payload)
@@ -171,11 +189,9 @@ class ContractPoint(FilterMixin, CacheMixin, Point):
     """Endpoints with validated data by contract"""
     _read_contract = None
     _create_contract = None
-    _response_contract = None
     _sort_by = 'id'
 
-    @property
-    def _sorted_data(self) -> tuple:
+    def _get_sorted_data(self) -> tuple:
         if self._sort_by is None:
             raise SortByNotSet('Set key for sort or False')
         validated_data = self._get_validated_data()
@@ -259,19 +275,7 @@ class ListPointMixin:
     def list(self) -> tuple:
         if self._read_contract is None:
             raise ContractNotSet(f'Set attr read_contract')
-        return self._sorted_data
-
-
-class GetResponseMixin:
-    """Only for create and update actions"""
-    def get_response(self):
-        if self._response_contract is None:
-            raise ContractNotSet('Response contract not set')
-        if self._response is None:
-            raise PointError('First create or update data')
-        contract = self._response_contract(data=self._response.json())
-        contract.is_valid(raise_exception=True)
-        return contract.validated_data
+        return self._get_sorted_data()
 
 
 class RetrievePointMixin:
@@ -283,7 +287,7 @@ class RetrievePointMixin:
         return self._get_validated_data()
 
 
-class CreatePointMixin(GetResponseMixin):
+class CreatePointMixin:
     """For type ContractPoint"""
 
     def create(self, payload: dict):
@@ -291,7 +295,6 @@ class CreatePointMixin(GetResponseMixin):
             raise ContractNotSet(f'Set attr create_contract')
         contract = self._get_contract(data=payload, is_read=False)
         self._post(contract.data)
-        return self.get_response()
 
 
 class UpdatePointMixin:
@@ -305,6 +308,24 @@ class UpdatePointMixin:
         self._put(contract.validated_data)
 
 
+class ResponseMixin:
+    """Only for create and update actions"""
+
+    _response_contract = None
+
+    @property
+    def response(self) -> OrderedDict:
+        if self._response_contract is None:
+            raise ContractNotSet('Response contract not set')
+        if self._response is None:
+            raise PointError('First create or update data')
+        if self._response.status_code != status.HTTP_201_CREATED:
+            raise PointError(f'Response data only for 201 status, current {self._response.status_code}')
+        contract = self._response_contract(data=self._response.json())
+        contract.is_valid(raise_exception=True)
+        return contract.validated_data
+
+
 class UploadFilePointMixin:
     """For any type Point"""
 
